kernel_into_kernel_process

Function kernel_into_kernel_process 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn kernel_into_kernel_process( kernel: &'static mut Kernel, ) -> Option<&'static mut Win32Process>
Create a kernel process insatance

This will consume kernel and free it later on.

Safety

kernel must be a valid reference to Kernel. After the function the reference to it becomes invalid.